build

package
v0.2.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2018 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildImage

func BuildImage(serverURL, outputType string, config []byte) (io.ReadCloser, error)

BuildImage builds given Linuxkit config and returns the image as io.ReadClose or error Note: you must call image.Close()

func ResolveLinuxkitConfig

func ResolveLinuxkitConfig(source string) (linuxkit []byte, err error)

ResolveLinuxkitConfig resolves and reads linuxkit config from given source. Source can be url or path to the file.

Types

This section is empty.

Source Files

  • utils.go

Jump to